@@ -16,7 +16,7 @@ this module will be included in the api
 """
 
 ########################
-def applyflags(xds, flags=None):
+def applyflags(xds, flags='FLAG'):
     """
     Apply flag variables to other data in Visibility Dataset
 
@@ -24,30 +24,25 @@ def applyflags(xds, flags=None):
     ----------
     xds : xarray.core.dataset.Dataset
         input Visibility Dataset
-    flags : list of str
-        list of data var names to use as flags. Default None uses all bool types
+    flags : list or str
+        data var name or list of names to use as flags. Default 'FLAG' uses the FLAG field
     Returns
     -------
     xarray.core.dataset.Dataset
         output Visibility Dataset
     """
-    import xarray
+    import numpy as np
 
-    new_xds = xarray.Dataset(attrs=xds.attrs)
+    flags = np.atleast_1d(flags)
     
-    # find all variables with bool data type to use as flags
-    if flags is None:
-        flags = [dv for dv in xds.data_vars if xds.data_vars[dv].dtype == 'bool']
-    
-    # apply flags to each variable of compatible shape
-    for dv in xds.data_vars:
-        if dv in flags: continue
+    flagged_xds = xds.copy()
+
+    # loop over each flag dimension
+    # flag each data var with matching dimensions
+    for fv in flags:
+        for dv in xds.data_vars:
+            if dv == fv: continue   # dont flag the flags
+            if flagged_xds[dv].dims == flagged_xds[fv].dims:
+                flagged_xds[dv] = flagged_xds[dv].where(flagged_xds[fv] == 0).astype(xds[dv].dtype)
         
-        xda = xds.data_vars[dv]
-        for flag in flags:
-            if xds.data_vars[flag].ndim <= xda.ndim:
-                xda = xda.where(~xds.data_vars[flag])
-        
-        new_xds = new_xds.assign(dict([(dv, xda)]))
-    
-    return new_xds
+    return flagged_xds
