@@ -1,3 +1,6 @@
+"""
+Imaging subpackage modules
+"""
 from .calc_image_cell_size import calc_image_cell_size
 from .phase_rotate import phase_rotate
 from .phase_rotate_numba import phase_rotate_numba
