@@ -1,3 +1,5 @@
-#__init__.py
+"""
+Simulator subpackage modules
+"""
 from .add_meta_data import add_meta_data
 from .add_noise import add_noise
\ No newline at end of file
